@@ -10,6 +10,8 @@
  ***************************************************************************/
 
 #include "common.h"
+#include "helpers.h"
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -19,7 +21,7 @@
 int open_myFile_ro (char* file) {
   int myfd;
 	
-  if (strlen(file) && strcmp(file,"-")) {
+  if (str_len(file) && strcmp(file,"-")) {
     myfd=open(file,O_RDONLY);
     if (myfd==-1) {
       errexit("Could not access %s: %s\nAborting\n",file, strerror(errno));
@@ -38,7 +40,7 @@ int open_myFile_ro (char* file) {
 int open_myFile_rw(char* file){
   int myfd;
 
-  if (strlen(file) && strcmp(file,"-")) {
+  if (str_len(file) && strcmp(file,"-")) {
     myfd=open(file ,O_RDWR|O_CREAT|O_EXCL, S_IRUSR|S_IWUSR|S_IRGRP);
     if (myfd==-1){
       close(myfd);
