@@ -21,11 +21,15 @@ void* mem_realloc (void* oldpointer, size_t size);
 char* str_dup (const char* input);
 char* strn_dup (const char* input, size_t insize);
 
-/*
- * These functions either read the length from the variable length or,
+/* These functions either read the length from the variable length or,
  * if <=0, will determine the needed size. The returns char* has to be
  * freed.
  */
 char* strn_printf(int length, char* input,...);
 char* strn_vprintf(int length, char* input, va_list* ap);
+
+/* strlen() does not seem to check for strlen(NULL) and crashes
+ */
+size_t str_len(const char *s);
+
 #endif
